@@ -89,11 +89,14 @@ def _create_aux_files(conanfile, copy_info):
     return manifest
 
 def _create_deb_file(conanfile):
+    output = conanfile.output
     #### set folder name
     package_name = conanfile.name
     package_version = conanfile.version
-    debian_folder = package_name + "/DEBIAN"
-    app_folder = package_name + "/sense2"
+    deb_folder = package_name
+    deb_file = package_name + "_" + package_version + ".deb"
+    debian_folder = deb_folder + "/DEBIAN"
+    app_folder = deb_folder + "/sense2"
         
     #### generate package in build
     mkdir(debian_folder)
@@ -129,10 +132,17 @@ def _create_deb_file(conanfile):
         conanfile.run(add_bin_cmd)
 
     ## generate deb package in build
-    build_package_cmd = "dpkg-deb --build " + package_name + " " + package_name + "_" + package_version + ".deb" 
+    build_package_cmd = "dpkg-deb --build " + deb_folder + " " + deb_file
     conanfile.run(build_package_cmd)
 
-    ## copy *.deb to deb folder
-    # deb_file = package_name + ".deb"
-    # conanfile.copy(deb_file, dst=".", keep_path=False)
+    ## copy *.deb in package folder to deb folder
+    conanfile.copy(deb_file, dst=".", keep_path=False)
+    output.success("copy '%s' to deb folder" % deb_file)
+    
+    ## clean package folder
+    if os.path.exists(deb_folder):
+            conanfile.run("rm -rf " + deb_folder)
+
+    if os.path.exists(deb_file):
+        conanfile.run("rm -rf " + deb_file)
     
\ No newline at end of file
